# SQUIRTCOPTER
### An Inifinite Shooter Game by Joachim


![image](https://user-images.githubusercontent.com/87899147/235861351-0dd38fc2-ed47-44ac-b4cf-95087a755def.png)


Use your helicopter to explore an infinite world. As the game continues, try to avaoid the ever-worsening enemies.
Upgrade your equipment at each checkpoint to become more powerful! How far can you get? The current record is 8581m, beat that!

Use the arrow keys, WASD or ZQSD to move around.

[JoachimFord.uk](https://joachimford.uk)
